This is a generic to represent direct instantiation of an implicitly defined
matrix. In general this is a bad idea, because it removes the whole purpose
of using an implicit representation.
Usage
instantiate(x)
# S4 method for GWoodburyMatrix
instantiate(x)
# S4 method for SWoodburyMatrix
instantiate(x)
Value
The directly instantiated matrix.
Arguments
x
Implicit matrix to directly instantiate.
Functions
instantiate(GWoodburyMatrix): Method for general matrices.
instantiate(SWoodburyMatrix): Method for symmetric matrices.